
.. image:: https://secure.travis-ci.org/codesyntax/bobtemplates.cs.png?branch=master
    :target: http://travis-ci.org/codesyntax/bobtemplates.cs

.. image:: https://coveralls.io/repos/github/codesyntax/bobtemplates.cs/badge.svg?branch=master
    :target: https://coveralls.io/github/codesyntax/bobtemplates.cs?branch=master
    :alt: Coveralls

.. image:: https://img.shields.io/pypi/dm/bobtemplates.cs.svg
    :target: https://pypi.python.org/pypi/bobtemplates.cs/
    :alt: Downloads

.. image:: https://img.shields.io/pypi/v/bobtemplates.cs.svg
    :target: https://pypi.python.org/pypi/bobtemplates.cs/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/status/bobtemplates.cs.svg
    :target: https://pypi.python.org/pypi/bobtemplates.cs/
    :alt: Egg Status

.. image:: https://img.shields.io/pypi/l/bobtemplates.cs.svg
    :target: https://pypi.python.org/pypi/bobtemplates.cs/
    :alt: License

================
bobtemplates.cs
================

`bobtemplates.cs` provides a `mr.bob <http://mrbob.readthedocs.org/en/latest/>`_ template to generate packages for Plone projects using our customizations. This packages is based on `bobtemplates.plone <https://pypi.python.org/project/bobtemplates.plone>`_


Features
========

Package created with ``bobtemplates.cs`` use the current best-practices when creating an add-on.

Provided templates
------------------

- cs_plone_buildout


Compatibility
=============

Add-ons created with ``bobtemplates.cs`` are tested to work in Plone 4.3.x and Plone 5.
They should also work with older versions but that was not tested.
It should work on Linux, Mac and Windows.


Documentation
=============

Full documentation for end users can be found in the "docs" folder.


Contribute
==========

- Issue Tracker: https://github.com/codesyntax/bobtemplates.cs/issues
- Source Code: https://github.com/codesyntax/bobtemplates.cs
- Documentation:


Support
=======

If you are having issues, please let us know.
